# frozen_string_literal: true

newparam(:name) do
  include EasyType

  desc <<-DESC
    The full name of the LDAP principal.

    a full name consist of an LDAP server a double colon and then a LDAP identifier
    narrowing down to one LDAP entry.

    Here is an example of a full qualified LDAP principal name:

        ldap_principal { 'ldap_server:cn=hajee,dc=example,dc=org':
          ...
        }

  DESC

  isnamevar

  data_type('Optional[String[1]]')

  munge do |name|
    name.split(',').collect(&:strip).join(',')
  end

  to_translate_to_resource do |raw_resource|
    "#{raw_resource['ldap_server'].first}:#{raw_resource.dn}"
  end
end
