# frozen_string_literal: true

require 'base64'
require 'digest'

module PuppetX
  module EnterpriseModules
    # docs
    module Transformers
      # @private
      def encrypted_compare(digest, secret, code, salted)
        code.delete!(' ')
        if salted
          decoded  = Base64.decode64(code)
          salt     = decoded[-8, 8]
        else
          salt = ''
        end
        digest << secret << salt
        hex_digest = Base64.encode64("#{digest.digest}#{salt}").delete("\n")
        hex_digest == code
      end

      def hashed_compare(secret, current_hash)
        raise 'Array value not supported on hashed value' if secret.is_a?(Array)
        return false if secret.nil? || current_hash.nil?

        type, code = current_hash.scan(/\{(.*)\}(.*)/m).first
        case type
        when nil
          Puppet.info "Hashing selected, but #{resource} returned value for is not hashed."
          secret == current_hash
        when 'SSHA512'
          encrypted_compare(Digest::SHA2.new(512), secret, code, true)
        when 'SHA512'
          encrypted_compare(Digest::SHA2.new(512), secret, code, false)
        when 'SSHA256'
          encrypted_compare(Digest::SHA2.new(256), secret, code, true)
        when 'SHA256'
          encrypted_compare(Digest::SHA2.new(256), secret, code, false)
        when 'SSHA'
          encrypted_compare(Digest::SHA1.new, secret, code, true)
        when 'SHA'
          encrypted_compare(Digest::SHA1.new, secret, code, false)
        when 'SMD5'
          encrypted_compare(Digest::MD5.new, secret, code, true)
        when 'MD5'
          encrypted_compare(Digest::MD5.new, secret, code, false)
        else
          raise "#{type} hashing not currently supported by hashed transformer"
        end
      end
    end
  end
end
